#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2008 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace HeuristicLab.Core {
  public partial class ParameterView : ViewBase {
    public IParameter Parameter {
      get { return (IParameter)Item; }
      set { base.Item = value; }
    }

    public ParameterView() {
      InitializeComponent();
      Caption = "Parameter";
    }
    public ParameterView(IParameter parameter)
      : this() {
      Parameter = parameter;
    }

    /// <summary>
    /// Updates all controls with the latest data of the model.
    /// </summary>
    /// <remarks>Calls <see cref="ViewBase.UpdateControls"/> of base class <see cref="ViewBase"/>.</remarks>
    protected override void UpdateControls() {
      base.UpdateControls();
      Caption = "Parameter";
      if (Parameter == null) {
        nameTextBox.Enabled = false;
        dataTypeTextBox.Enabled = false;
        typeTextBox.Enabled = false;
        descriptionTextBox.Enabled = false;
      } else {
        Caption = Parameter.Name + " (" + Parameter.GetType().Name + ")";
        nameTextBox.Text = Parameter.Name;
        nameTextBox.Enabled = true;
        dataTypeTextBox.Text = Parameter.DataType.FullName;
        dataTypeTextBox.Enabled = true;
        typeTextBox.Text = Parameter.Type.ToString();
        typeTextBox.Enabled = true;
        descriptionTextBox.Text = Parameter.Description;
        descriptionTextBox.Enabled = true;
      }
    }
  }
}
